part of pdf;

/// A class representing PDF page margins.
class PdfMargins {
  //Constructor
  /// Initializes a new instance of the [PdfMargins] class.
  PdfMargins() {
    _setMargins(0);
  }

  //Fields
  double _left;
  double _top;
  double _right;
  double _bottom;
  bool _isPageAdded = false;

  //Properties
  /// Gets or sets the left margin size.
  double get left => _left;
  set left(double value) {
    ArgumentError.checkNotNull(value, 'left');
    if (_left != value && !_isPageAdded) {
      _left = value;
    }
  }

  /// Gets or sets the top margin size.
  double get top => _top;
  set top(double value) {
    ArgumentError.checkNotNull(value, 'top');
    if (_top != value && !_isPageAdded) {
      _top = value;
    }
  }

  /// Gets or sets the right margin size.
  double get right => _right;
  set right(double value) {
    ArgumentError.checkNotNull(value, 'right');
    if (_right != value && !_isPageAdded) {
      _right = value;
    }
  }

  /// Gets or sets the bottom margin size.
  double get bottom => _bottom;
  set bottom(double value) {
    ArgumentError.checkNotNull(value, 'bottom');
    if (_bottom != value && !_isPageAdded) {
      _bottom = value;
    }
  }

  /// Sets the margins of all side.
  set all(double value) {
    if (!_isPageAdded) {
      _setMargins(value);
    }
  }

  //Implementation
  void _setMargins(double margin) {
    left = top = right = bottom = margin;
  }

  void _setMarginsLT(double leftRight, double topBottom) {
    left = right = leftRight;
    top = bottom = topBottom;
  }

  void _setMarginsAll(double l, double t, double r, double b) {
    left = l;
    right = r;
    top = t;
    bottom = b;
  }

  bool _equals(PdfMargins margins) {
    return _left == margins.left &&
        _top == margins._top &&
        _right == margins._right &&
        _bottom == margins._bottom;
  }

  PdfMargins _clone() {
    final PdfMargins result = PdfMargins();
    result.left = left.toDouble();
    result.right = right.toDouble();
    result.top = top.toDouble();
    result.bottom = bottom.toDouble();
    return result;
  }
}
